==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/da/mail.php <==
<?php

return array(
    'a_user_canceled' => 'En bruger har annulleret en vareforespørgsel på hjemmesiden',
    'a_user_requested' => 'En bruger har anmodet om et emne på hjemmesiden',
    'accessory_name' => 'Tilbehør Navn:',
    'additional_notes' => 'Yderligere bemærkninger:',
    'admin_has_created' => 'En administrator har oprettet en konto til dig på webstedet:.',
    'asset' => 'aktiv:',
    'asset_name' => 'Aktivnavn:',
    'asset_requested' => 'Aktiver bedt om',
    'asset_tag' => 'Asset Tag:',
    'assigned_to' => 'Tildelt',
    'best_regards' => 'Med venlig hilsen,',
    'canceled' => 'annulleret:',
    'checkin_date' => 'Checkin dato:',
    'checkout_date' => 'Checkout dato:',
    'click_to_confirm' => 'Venligst klik på følgende link for at bekræfte din: web-konto:',
    'click_on_the_link_accessory' => 'Venligst klik på linket nederst for at bekræfte, at du har modtaget tilbehør.',
    'click_on_the_link_asset' => 'Klik venligst på linket nederst for at bekræfte, at du har modtaget aktivet.',
    'Confirm_Asset_Checkin' => 'Asset checkin bekræftelse',
    'Confirm_Accessory_Checkin' => 'Tilbehør checkin bekræftelse',
    'Confirm_accessory_delivery' => 'Tilbehør leveringsbekræftelse',
    'Confirm_license_delivery' => 'Licens leveringsbekræftelse',
    'Confirm_asset_delivery' => 'Asset leveringsbekræftelse',
    'Confirm_consumable_delivery' => 'Forbrugsvare leveringsbekræftelse',
    'current_QTY' => 'Nuværende QTY',
    'Days' => 'Dage',
    'days' => 'Dage',
    'expecting_checkin_date' => 'Forventet Checkin Date:',
    'expires' => 'udløber',
    'Expiring_Assets_Report' => 'Udløbsaktiver Rapport.',
    'Expiring_Licenses_Report' => 'Udløber Licenser Rapport.',
    'hello' => 'Hej',
    'hi' => 'Hej',
    'i_have_read' => 'Jeg har læst og accepterer vilkårene for brug og har modtaget denne vare.',
    'item' => 'Vare:',
    'Item_Request_Canceled' => 'Elementforespørgsel annulleret',
    'Item_Requested' => 'Vareanmodning',
    'link_to_update_password' => 'Venligst klik på følgende link for at opdatere din: webadgangskode:',
    'login_first_admin' => 'Log ind på din nye Snipe-IT-installation ved hjælp af nedenstående referencer:',
    'login' => 'Log på:',
    'Low_Inventory_Report' => 'Lav lagerrapport',
    'min_QTY' => 'Min QTY',
    'name' => 'Navn',
    'new_item_checked' => 'En ny vare er blevet tjekket ud under dit navn, detaljerne er nedenfor.',
    'password' => 'Adgangskode:',
    'password_reset' => 'Nulstil kodeord',

    'read_the_terms' => 'Læs venligst brugsbetingelserne nedenfor.',
    'read_the_terms_and_click' => 'Læs venligst brugsbetingelserne nedenfor, og klik på linket nederst for at bekræfte, at du læser og accepterer vilkårene for brug og har modtaget aktivet.',
    'requested' => 'Anmodede om:',
    'reset_link' => 'Din Password Reset Link',
    'reset_password' => 'Klik her for at nulstille adgangskoden:',
    'serial' => 'Seriel',
    'supplier' => 'Leverandør',
    'tag' => 'Mærkat',
    'test_email' => 'Test E-mail fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT Asset Management System. Hvis du fik dette, virker mailen :)',
    'the_following_item' => 'Følgende vare er blevet kontrolleret i:',
    'low_inventory_alert' => 'Der er :count enhed som er under minimum lagertal eller som snart vil være det.|Der er :count enheder som er under minimum lagertal eller som snart vil være det.',
    'assets_warrantee_alert' => 'Der er :count aktiv(er) hvor garantien udløber indenfor de næste :threshold dage.',
    'license_expiring_alert' => 'Der er :count licens(er) der udløber indenfor den/de næste :threshold dag(e).',
    'to_reset' => 'Nulstille din :web-adgangskode, udfylde denne formular:',
    'type' => 'Type',
    'upcoming-audits' => 'Der er :count asset, som skal tilses inden :threshold dage. |Der er :count assets, som skal tilses inden :threshold dage.',
    'user' => 'Bruger',
    'username' => 'Brugernavn',
    'welcome' => 'Velkommen :navn',
    'welcome_to' => 'Velkommen til :web!',
    'your_credentials' => 'Dine Snipe-IT Legitimationsoplysninger',
    'Accessory_Checkin_Notification' => 'Tilbehør tjekket ind',
    'Asset_Checkin_Notification' => 'Asset tjekket ind',
    'License_Checkin_Notification' => 'Licens tjekket ind',
    'Expected_Checkin_Report' => 'Forventet asset checkin rapport',
    'Expected_Checkin_Notification' => 'Påmindelse: :name checkin deadline nærmer sig',
    'Expected_Checkin_Date' => 'Et asset tjekket ud til dig skal tjekkes tilbage den :date',
    'your_assets' => 'Se dine assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/da/mail.php <==
<?php

return [
    'a_user_canceled' => 'En bruger har annulleret en vareforespørgsel på hjemmesiden',
    'a_user_requested' => 'En bruger har anmodet om et emne på hjemmesiden',
    'accessory_name' => 'Tilbehør Navn:',
    'additional_notes' => 'Yderligere bemærkninger:',
    'admin_has_created' => 'En administrator har oprettet en konto til dig på webstedet:.',
    'asset' => 'aktiv:',
    'asset_name' => 'Aktivnavn:',
    'asset_requested' => 'Aktiver bedt om',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Tildelt',
    'best_regards' => 'Med venlig hilsen,',
    'canceled' => 'annulleret:',
    'checkin_date' => 'Checkin dato:',
    'checkout_date' => 'Checkout dato:',
    'click_to_confirm' => 'Venligst klik på følgende link for at bekræfte din: web-konto:',
    'click_on_the_link_accessory' => 'Venligst klik på linket nederst for at bekræfte, at du har modtaget tilbehør.',
    'click_on_the_link_asset' => 'Klik venligst på linket nederst for at bekræfte, at du har modtaget aktivet.',
    'Confirm_Asset_Checkin' => 'Asset checkin bekræftelse',
    'Confirm_Accessory_Checkin' => 'Tilbehør checkin bekræftelse',
    'Confirm_accessory_delivery' => 'Tilbehør leveringsbekræftelse',
    'Confirm_license_delivery' => 'Licens leveringsbekræftelse',
    'Confirm_asset_delivery' => 'Asset leveringsbekræftelse',
    'Confirm_consumable_delivery' => 'Forbrugsvare leveringsbekræftelse',
    'current_QTY' => 'Nuværende QTY',
    'Days' => 'Dage',
    'days' => 'Dage',
    'expecting_checkin_date' => 'Forventet Checkin Date:',
    'expires' => 'udløber',
    'Expiring_Assets_Report' => 'Udløbsaktiver Rapport.',
    'Expiring_Licenses_Report' => 'Udløber Licenser Rapport.',
    'hello' => 'Hej',
    'hi' => 'Hej',
    'i_have_read' => 'Jeg har læst og accepterer vilkårene for brug og har modtaget denne vare.',
    'item' => 'Vare:',
    'Item_Request_Canceled' => 'Elementforespørgsel annulleret',
    'Item_Requested' => 'Vareanmodning',
    'link_to_update_password' => 'Venligst klik på følgende link for at opdatere din: webadgangskode:',
    'login_first_admin' => 'Log ind på din nye Snipe-IT-installation ved hjælp af nedenstående referencer:',
    'login' => 'Log på:',
    'Low_Inventory_Report' => 'Lav lagerrapport',
    'min_QTY' => 'Min QTY',
    'name' => 'Navn',
    'new_item_checked' => 'En ny vare er blevet tjekket ud under dit navn, detaljerne er nedenfor.',
    'password' => 'Adgangskode:',
    'password_reset' => 'Nulstil kodeord',

    'read_the_terms' => 'Læs venligst brugsbetingelserne nedenfor.',
    'read_the_terms_and_click' => 'Læs venligst brugsbetingelserne nedenfor, og klik på linket nederst for at bekræfte, at du læser og accepterer vilkårene for brug og har modtaget aktivet.',
    'requested' => 'Anmodede om:',
    'reset_link' => 'Din Password Reset Link',
    'reset_password' => 'Klik her for at nulstille adgangskoden:',
    'serial' => 'Seriel',
    'supplier' => 'Leverandør',
    'tag' => 'Mærkat',
    'test_email' => 'Test E-mail fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT Asset Management System. Hvis du fik dette, virker mailen :)',
    'the_following_item' => 'Følgende vare er blevet kontrolleret i:',
    'low_inventory_alert' => 'Der er :count enhed som er under minimum lagertal eller som snart vil være det.|Der er :count enheder som er under minimum lagertal eller som snart vil være det.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Der er :count licens(er) der udløber indenfor den/de næste :threshold dag(e).',
    'to_reset' => 'Nulstille din :web-adgangskode, udfylde denne formular:',
    'type' => 'Type',
    'upcoming-audits' => 'Der er :count asset, som skal tilses inden :threshold dage. |Der er :count assets, som skal tilses inden :threshold dage.',
    'user' => 'Bruger',
    'username' => 'Brugernavn',
    'welcome' => 'Velkommen :navn',
    'welcome_to' => 'Velkommen til :web!',
    'your_credentials' => 'Dine Snipe-IT Legitimationsoplysninger',
    'Accessory_Checkin_Notification' => 'Tilbehør tjekket ind',
    'Asset_Checkin_Notification' => 'Asset tjekket ind',
    'License_Checkin_Notification' => 'Licens tjekket ind',
    'Expected_Checkin_Report' => 'Forventet asset checkin rapport',
    'Expected_Checkin_Notification' => 'Påmindelse: :name checkin deadline nærmer sig',
    'Expected_Checkin_Date' => 'Et asset tjekket ud til dig skal tjekkes tilbage den :date',
    'your_assets' => 'Se dine assets',
];
